# samanage-py 

> Detailed usage documentation is still in progress

My personal package to easily connect to Samanage ServiceDesk Platform. This is still a work in progress and doesn't support all modules provided by Samanage API but will add it in the future.


## Installation
```bash
pip intall samanage-py
```

Project dependencies:
  - requests

## Usage
```python
from samanage import Samanage
client = Samanage(<token here>)
```